from rest_framework import serializers

from .models import ClassDescription, Country, FeatureClass, Place


class ClassDescriptionSerializer(serializers.ModelSerializer):
    class Meta:
        model = ClassDescription
        fields = ['title']


class CountrySerializer(serializers.ModelSerializer):
    class Meta:
        model = Country
        fields = ['name', 'code']


class FeatureClassSerializer(serializers.ModelSerializer):
    class Meta:
        model = FeatureClass
        fields = ['title']


class PlaceSerializer(serializers.ModelSerializer):
    class_description = ClassDescriptionSerializer(many=False, read_only=True)
    country = CountrySerializer(many=False, read_only=True)
    feature_class = FeatureClassSerializer(many=False, read_only=True)

    class Meta:
        model = Place
        fields = ['geonames_id', 'address', 'class_description',
                  'country', 'feature_class', 'lat', 'lon']



from django.contrib import admin
from geonames_place.models import ClassDescription, Country, FeatureClass, Place


@admin.register(ClassDescription)
class ClassDescriptionAdmin(admin.ModelAdmin):
    search_fields = ["title"]


@admin.register(Country)
class CountryAdmin(admin.ModelAdmin):
    search_fields = ["name", "code"]


@admin.register(FeatureClass)
class FeatureClassAdmin(admin.ModelAdmin):
    search_fields = ["title"]


@admin.register(Place)
class PlaceAdmin(admin.ModelAdmin):
    autocomplete_fields = ["class_description", "country", "feature_class"]
    list_display = ["address", "class_description", "country"]
    list_filter = ["class_description", "country"]
    search_fields = ["address", "country__name", "country__code"]

    def get_search_results(self, request, queryset, search_term):
        queryset, use_distinct = super().get_search_results(
            request, queryset, search_term
        )

        if len(queryset) < 3 and len(search_term) > 3:
            Place.create_or_update_from_geonames(search_term)
            queryset, use_distinct = super().get_search_results(
                request, queryset, search_term
            )

        return queryset, use_distinct



# Generated by Django 2.1.3 on 2018-11-15 15:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geonames_place', '0003_place_update_from_geonames'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='country',
            options={'ordering': ['name', 'code'], 'verbose_name_plural': 'Countries'},
        ),
    ]
